package ai.pai.lensman.login;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.text.SpannableString;
import android.text.TextUtils;
import android.text.style.UnderlineSpan;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.android.common.utils.LogHelper;
import com.android.views.progressbar.ProgressWheel;

import java.io.File;

import ai.pai.lensman.R;
import ai.pai.lensman.activities.WebViewActivity;
import ai.pai.lensman.dslr.CameraJNIInterface;
import ai.pai.lensman.main.MainActivity;
import ai.pai.lensman.service.Constants;
import ai.pai.lensman.utils.ImageLoaderUtils;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class LoginActivity extends FragmentActivity implements LoginContract.View{

    @BindView(R.id.wheel_wait_http)    ProgressWheel progressWheel;
    @BindView(R.id.tv_agree_protocol)  TextView protocolText;
    @BindView(R.id.iv_login_logo)      ImageView photoView;
    private LoginContract.Presenter presenter;
    private boolean isCancelled;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_login);
        ButterKnife.bind(this);
        SpannableString content = new SpannableString(getString(R.string.agree_protocol));
        content.setSpan(new UnderlineSpan(), 6, content.length(), 0);
        protocolText.setText(content);
        presenter = new LoginPresenter(this,this);
        int ret = CameraJNIInterface.getInstance().mygpcamerainit();
        if(ret>=0){
            String text = CameraJNIInterface.getInstance().mygpcameragetsummary();
            LogHelper.d("czy","text="+text);
            protocolText.setText("text="+text);
//            Toast.makeText(this,text,Toast.LENGTH_LONG).show();
        }else{
            LogHelper.d("czy","ret="+ret);
//            Toast.makeText(this,"camera init return "+ret,Toast.LENGTH_LONG).show();
            protocolText.setText("camera init return "+ret);
        }
        File dir = new File(Constants.APP_IMAGE_DIR);
        dir.mkdirs();
        fetchPhotoTask();
    }

    private void fetchPhotoTask(){
        new Thread(new Runnable() {
            @Override
            public void run() {
                while (!isCancelled){
                    final String photoName = CameraJNIInterface.getInstance().mygpcamerawaitforevent(Constants.APP_IMAGE_DIR);
                    LogHelper.d("czy","mygpcamerawaitforevent return "+photoName);
                    photoView.post(new Runnable() {
                        @Override
                        public void run() {
                            protocolText.setText("mygpcamerawaitforevent return "+photoName);
                            if(photoName!=null && photoName.length()>0){
                                String sub = photoName.substring(0,1);
                                if(TextUtils.isDigitsOnly(sub)){
                                    ImageLoaderUtils.displayLocalImage(Constants.APP_IMAGE_DIR+File.separator+photoName,photoView,ImageLoaderUtils.getOptions(R.drawable.login_page_logo));
                                }
                            }

                        }
                    });
                }
            }
        }).start();

    }

    @Override
    protected void onResume() {
        super.onResume();
        presenter.start();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        CameraJNIInterface.getInstance().mygpcameraexit();
        isCancelled = true;
    }

    @OnClick(R.id.btn_login)
    public void login(){
        presenter.login();
    }

    @OnClick(R.id.tv_agree_protocol)
    public void jump2Protocol(){
        Intent declareIntent = new Intent(this,WebViewActivity.class);
        declareIntent.putExtra("url","http://pai.ai/page/user_agreement");
        declareIntent.putExtra("title",getString(R.string.contract));
        startActivity(declareIntent);
    }

    @Override
    public void showLoginHint(String hint) {
        if(TextUtils.isEmpty(hint)){
            return;
        }
        Toast.makeText(this,hint,Toast.LENGTH_SHORT).show();
    }

    @Override
    public void showProgressView() {
        progressWheel.setVisibility(View.VISIBLE);
        progressWheel.startSpinning();
    }

    @Override
    public void hideProgressView() {
        progressWheel.stopSpinning();
        progressWheel.setVisibility(View.GONE);
    }

    @Override
    public void jumpMain() {
        startActivity(new Intent(this, MainActivity.class));
        finish();
    }

}
